### Faster ≠ smarter: children with higher levels of ability take longer to give incorrect answers, especially when the task matches their ability
##  The plot script
#   The data and other supplementary materials can be accessed via: https://osf.io/dhu7f/

### This script allows the users to replicate the plots presented in the manuscript as Figures 2 and 3.
#   In order to successfully run this script, the code from analytic_script.R located in the same repository (https://osf.io/dhu7f/) need to be run.


#### PACKAGES ####

## install (if necessary)
list.of.packages <- c("ggplot2", "ggeffects", "signs", "extrafont")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
print(paste(length(not_installed), "packages had to be installed."))

## load
library(ggplot2)
library(ggeffects)
library(signs)

# extrafont has compatibility issues on some devices
# in case of any issues, alternative objects "figure.2.no.font" and "figure.4.no.font" can be used to get the plots in basic font setting
library(extrafont)
# font_import() # need to be used only once to import fonts in your device to R
# loadfonts() # only necessary in session where you ran font_import()



#### FIGURE 2 ####

# compute predicted values of Model A3 as a data source for the plot
figure.2.data <- ggpredict(model.a3, terms = c("ability [all]", "correct"))

# plot syntax
figure.2 <- plot(figure.2.data, ci = TRUE, ci.style = c("ribbon"), line.size = 0.75) + 
  labs(x = "ability (θ)", y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = -5:5, limits = c(-4, 4), labels = signs_format()) + 
  scale_y_continuous(breaks = seq(0, 50, by = 10), limits = c(0, 50)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  scale_fill_manual(values = c("#DB060B", "#4DB264")) + 
  theme_bw(base_size = 11, base_family = "Palatino Linotype") + 
  theme(axis.text = element_text(color = "black"))
 


# visualize the plot
figure.2

# save the plot in your device (located in your set working directory)
ggsave(figure.2, file = "Figure_2.jpeg", width = 14, height = 9.5, units = "cm")


# alternative plot syntax without custom font setting
figure.2.no.font <- plot(figure.2.data, ci = TRUE, ci.style = c("ribbon"), line.size = 0.75) + 
  labs(x = "ability (θ)", y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = -5:5, limits = c(-4, 4), labels = signs_format()) + 
  scale_y_continuous(breaks = seq(0, 50, by = 10), limits = c(0, 50)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  scale_fill_manual(values = c("#DB060B", "#4DB264")) + 
  theme_bw(base_size = 11) + 
  theme(axis.text = element_text(color = "black"))



#### FIGURE 3 ####

# compute predicted values of Model A4 as a data source for the plot
figure.3.data <- ggpredict(model.a4, terms = c("ability [all]", "correct", "difficulty [-2:2 by=2]"))

# plot syntax
figure.3 <- plot(figure.3.data, ci = TRUE, ci.style = c("ribbon"), line.size = 0.75) + 
  labs(x = "ability (θ)", y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = seq(-6, 6, by = 2), limits = c(-4, 4), labels = signs_format()) + 
  scale_y_continuous(breaks = seq(0, 50, by = 10), limits = c(0, 50)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  scale_fill_manual(values = c("#DB060B", "#4DB264")) + 
  theme_bw(base_size = 11, base_family = "Palatino Linotype") + 
  theme(axis.text = element_text(color = "black"))

# visualize the plot
figure.3

# save the plot in your device (located in your set working directory)
ggsave(figure.3, file = "Figure_3.jpeg", width = 14, height = 9.5, units = "cm")


# alternative plot syntax without custom font setting
figure.3.no.font <- plot(figure.3.data, ci = TRUE, ci.style = c("ribbon"), line.size = 0.75) + 
  labs(x = "ability (θ)", y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = seq(-6, 6, by = 2), limits = c(-4, 4), labels = signs_format()) + 
  scale_y_continuous(breaks = seq(0, 50, by = 10), limits = c(0, 50)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  scale_fill_manual(values = c("#DB060B", "#4DB264")) + 
  theme_bw(base_size = 11) + 
  theme(axis.text = element_text(color = "black"))



#### FIGURE 4 ####

# compute predicted values of Model B3 as a data source for the plot
figure.4.data <- ggpredict(model.b3, terms = c("distance_abs [all]", "correct"))

# creating symmetrical negative part of the data
figure.4.data.neg <- figure.4.data
figure.4.data.neg$x <- -figure.4.data.neg$x
figure.4.data <- rbind(figure.4.data, figure.4.data.neg)

# plot syntax
figure.4 <- plot(figure.4.data, line.size = 0.75) + 
  labs(x = expression(paste("ability-difficulty distance (θ – ", italic(b), ")"), sep = ""), 
       y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = seq(-8, 8, by = 2), limits = c(-7, 7), labels = signs_format()) +
  scale_y_continuous(breaks = seq(0, 40, by = 10), limits = c(0, 43)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  scale_fill_manual(values = c("#DB060B", "#4DB264")) + 
  theme_bw(base_size = 11, base_family = "Palatino Linotype") + 
  theme(axis.text = element_text(color = "black"))

# visualize the plot
figure.4

# save the plot in your device (located in your set working directory)
ggsave(figure.4, file = "Figure_4.jpeg", width = 14, height = 9.5, units = "cm")


# alternative plot syntax without custom font setting
figure.4.no.font <- plot(figure.4.data, line.size = 0.75) + 
  labs(x = expression(paste("ability-difficulty distance (θ − ", italic("b"), ")", sep = "")), 
       y = "reponse time (in seconds)", title = NULL, color = "response") + 
  scale_x_continuous(breaks = seq(-8, 8, by = 2), limits = c(-7, 7), labels = signs_format()) +
  scale_y_continuous(breaks = seq(0, 40, by = 10), limits = c(0, 40)) + 
  scale_color_manual(values = c("#DB060B", "#4DB264"), labels = c("false", "correct")) + 
  theme_bw(base_size = 11) + 
  theme(axis.text = element_text(color = "black"))

