### Faster ≠ smarter: children with higher levels of ability take longer to give incorrect answers, especially when the task matches their ability
##  Sensitivity analysis
#   The data and other supplementary materials can be accessed via: https://osf.io/dhu7f/

### This script allows the users to replicate the sensitivity analysis simulations based on models in the study.
#   In order to successfully run this script, the code from analytic_script.R located in the same repository (https://osf.io/dhu7f/) need to be run.


#### PACKAGES ####

## install (if necessary)
list.of.packages <- c("ggplot2", "ggeffects", "extrafont", "devtools")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
print(paste(length(not_installed), "packages had to be installed."))

devtools::install_github("DejanDraschkow/mixedpower") 


## load
library(mixedpower)


## Since the simulations can take several hours to compute, the data file containing the results of our simulations can be loaded in this file
# load("sensitivity_analysis_results.RData")

## print the results
# power.a3
# power.b3



#### SENSITIVITY ANALYSIS OF MODEL A3 ####

## simulation syntax
power.a3 <- R2power(model = model.a3, data = triton.data.long, fixed_effects = c("correct", "difficulty", "ability"), 
                    simvar = "id", steps = seq(50, 400, by = 50), R2var = "item", R2level = 29,
                    critical_value = qnorm(0.975), n_sim = 100, databased = TRUE, maxCores = 1)
  # parameter "steps" indicate simulated sample size, our option were steps from 50 to 400
  # number of simulations were reduced to 100, since the process was too long



#### SENSITIVITY ANALYSIS OF MODEL B3 ####

## simulation syntax
power.b3 <- R2power(model = model.b3, data = triton.data.long, fixed_effects = c("distance", "correct"),
                    simvar = "id", steps = seq(50, 400, by = 50), R2var = "item", R2level = 29,
                    critical_value = qnorm(0.975), n_sim = 1000, databased = TRUE, maxCores = 6)
  # parameter "steps" indicate simulated sample size, our option were steps from 50 to 400
  # number of simulations were reduced to 100, since the process was too long
